# SearchSource: CoLRev Project

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

## Add the search source

```
colrev search -a colrev.colrev_project -p "/path/to/local/file.bib"
```

## Links
